@@ -117,7 +117,7 @@ class Op_outlist(Op):
         import inspect
         from . import mylogger
 
-        mylog = mylogger.logging.getLogger("PyBDSM."+img.log+"Output")
+        mylog = mylogger.logging.getLogger("PyBDSF."+img.log+"Output")
         fname = 'parameters_used'
         f = open(dir+fname, 'w')
         mylog.info('Writing '+dir+fname)
@@ -139,11 +139,11 @@ class Op_outlist(Op):
         f.close()
 
     def save_opts(self, img, dir):
-        """ Saves input parameters to a PyBDSM save file."""
+        """ Saves input parameters to a PyBDSF save file."""
         from . import interface
         from . import mylogger
 
-        mylog = mylogger.logging.getLogger("PyBDSM."+img.log+"Output")
+        mylog = mylogger.logging.getLogger("PyBDSF."+img.log+"Output")
         fname = 'parameters.sav'
         mylog.info('Writing '+dir+fname)
         interface.save_pars(img, dir+fname, quiet=True)
@@ -215,7 +215,7 @@ def write_bbs_gaul(img, filename=None, srcroot=None, patch=None,
     from . import mylogger
     import os
 
-    mylog = mylogger.logging.getLogger("PyBDSM.write_gaul")
+    mylog = mylogger.logging.getLogger("PyBDSF.write_gaul")
     if int(img.equinox) != 2000 and int(img.equinox) != 1950:
         mylog.warning('Equinox of input image is not J2000 or B1950. '
                       'Sky model may not be appropriate for BBS.')
@@ -247,7 +247,7 @@ def write_lsm_gaul(img, filename=None, srcroot=None, patch=None,
     from . import mylogger
     import os
 
-    mylog = mylogger.logging.getLogger("PyBDSM.write_gaul")
+    mylog = mylogger.logging.getLogger("PyBDSF.write_gaul")
     if int(img.equinox) != 2000 and int(img.equinox) != 1950:
         mylog.warning('Equinox of input image is not J2000 or B1950. '
                       'Sky model may not be appropriate for Sagecal.')
@@ -277,7 +277,7 @@ def write_ds9_list(img, filename=None, srcroot=None, deconvolve=False,
     from . import mylogger
     import os
 
-    mylog = mylogger.logging.getLogger("PyBDSM."+img.log+"Output")
+    mylog = mylogger.logging.getLogger("PyBDSF."+img.log+"Output")
     if objtype == 'gaul':
         outl, outn, patl = list_and_sort_gaussians(img, patch=None)
     elif objtype == 'srl':
@@ -316,7 +316,7 @@ def write_ascii_list(img, filename=None, sort_by='indx', format='ascii',
     from . import mylogger
     import os
 
-    mylog = mylogger.logging.getLogger("PyBDSM."+img.log+"Output")
+    mylog = mylogger.logging.getLogger("PyBDSF."+img.log+"Output")
     if objtype == 'gaul':
         outl, outn, patl = list_and_sort_gaussians(img, patch=None, sort_by=sort_by)
     elif objtype == 'srl':
@@ -346,7 +346,7 @@ def write_casa_gaul(img, filename=None,  incl_empty=False, clobber=False):
     from . import mylogger
     import os
 
-    mylog = mylogger.logging.getLogger("PyBDSM."+img.log+"Output")
+    mylog = mylogger.logging.getLogger("PyBDSF."+img.log+"Output")
     outl, outn, patl = list_and_sort_gaussians(img, patch=None)
     outstr_list = make_casa_str(img, outl)
     if filename is None:
@@ -371,7 +371,7 @@ def write_fits_list(img, filename=None, sort_by='index', objtype='gaul',
     from astropy.io import fits as pyfits
     from ._version import __version__
 
-    mylog = mylogger.logging.getLogger("PyBDSM."+img.log+"Output")
+    mylog = mylogger.logging.getLogger("PyBDSF."+img.log+"Output")
     if objtype == 'gaul':
         outl, outn, patl = list_and_sort_gaussians(img, patch=None, sort_by=sort_by)
     elif objtype == 'srl':
@@ -421,7 +421,7 @@ def write_fits_list(img, filename=None, sort_by='index', objtype='gaul',
         tbhdu.header.add_comment('Source list for '+img.filename)
     elif objtype == 'shap':
         tbhdu.header.add_comment('Shapelet list for '+img.filename)
-    tbhdu.header.add_comment('Generated by PyBDSM version %s'
+    tbhdu.header.add_comment('Generated by PyBDSF version %s'
                              % (__version__, ))
     freq = "%.5e" % img.frequency
     tbhdu.header.add_comment('Reference frequency of the detection ("ch0") image: %s Hz' % freq)
@@ -454,7 +454,7 @@ def write_kvis_ann(img, filename=None, sort_by='indx',
     from . import mylogger
     import os
 
-    mylog = mylogger.logging.getLogger("PyBDSM."+img.log+"Output")
+    mylog = mylogger.logging.getLogger("PyBDSF."+img.log+"Output")
     if filename is None:
         filename = img.imagename + '.kvis.ann'
     if os.path.exists(filename) and not clobber:
@@ -488,7 +488,7 @@ def write_star(img, filename=None, sort_by='indx',
     from . import mylogger
     import os
 
-    mylog = mylogger.logging.getLogger("PyBDSM."+img.log+"Output")
+    mylog = mylogger.logging.getLogger("PyBDSF."+img.log+"Output")
     if filename is None:
         filename = img.imagename + '.star'
     if os.path.exists(filename) and not clobber:
@@ -621,7 +621,7 @@ def make_lsm_str(img, glist, gnames, incl_empty=False):
 
     outstr_list = ["# SAGECAL sky model\n"]
     freq = "%.5e" % img.frequency
-    outstr_list.append('# Generated by PyBDSM version %s\n'
+    outstr_list.append('# Generated by PyBDSF version %s\n'
                        % (__version__, ))
     outstr_list.append("# Name  | RA (hr,min,sec) | DEC (deg,min,sec) | I | Q | U | V | SI | RM | eX | eY | eP | freq0\n\n")
     for gindx, g in enumerate(glist[0]):
@@ -686,7 +686,7 @@ def make_ds9_str(img, glist, gnames, deconvolve=False, objtype='gaul', incl_empt
         elif int(img.equinox) == 1950:
             equinox = 'fk4'
         else:
-            mylog = mylogger.logging.getLogger("PyBDSM.write_ds9")
+            mylog = mylogger.logging.getLogger("PyBDSF.write_ds9")
             mylog.warning('Equinox of input image is not J2000 or B1950. '
                           'Regions may not be correct.')
             equinox = 'fk5'
@@ -741,7 +741,7 @@ def make_ascii_str(img, glist, objtype='gaul', format='ascii', incl_empty=False,
         outstr_list.append('# Gaussian list for '+img.filename+'\n')
     elif objtype == 'srl':
         outstr_list.append('# Source list for '+img.filename+'\n')
-    outstr_list.append('# Generated by PyBDSM version %s\n'
+    outstr_list.append('# Generated by PyBDSF version %s\n'
                        % (__version__, ))
     outstr_list.append('# Reference frequency of the detection ("ch0") image: %s Hz\n' % freq)
     outstr_list.append('# Equinox : %s \n\n' % img.equinox)
@@ -971,7 +971,7 @@ def list_and_sort_gaussians(img, patch=None, root=None,
         # mask file.
         if 0 in unique_patch_ids:
             from . import mylogger
-            mylog = mylogger.logging.getLogger("PyBDSM.write_gaul")
+            mylog = mylogger.logging.getLogger("PyBDSF.write_gaul")
             mylog.warning('Some sources fall outside of the regions '
                           'defined in the mask file. These sources are not '
                           'included in the output sky model.')
